@@ -1,7 +1,6 @@
 import igraph as ig
 import numpy as np
-from pathlib import Path
-import sys, random, time, pickle
+import sys, random, os, time
 try:
     from ctns.generator import generate_network, init_infection
     from ctns.steps import step
@@ -11,7 +10,8 @@ except ImportError as e:
     from steps import step
     from utility import dump_network, compute_IR
 
-def run_simulation(n_of_families = 500,
+def run_simulation(path,
+    n_of_families = 500,
     use_steps = True,
     number_of_steps = 150,
     incubation_days = 5,
@@ -26,16 +26,17 @@ def run_simulation(n_of_families = 500,
     policy_test = "Random",
     contact_tracking_efficiency = 0.8,
     use_random_seed = None,
-    seed = None,
-    dump = False,
-    path = None):
+    seed = None):
 
     """
-    Execute the simulation and dump/return resulting networks
+    Execute the simulation and dump resulting networks
 
     Parameters
     ----------
     
+    path:string
+        The path to the folder where the networks will be saved
+
     n_of_families: int
         Number of families in the network
         
@@ -55,7 +56,7 @@ def run_simulation(n_of_families = 500,
         Day index from when social distancing measures are applied
 
     restriction_duration: int
-        How many days the social distancing last. Use 0 to make the restriction last till the end of the simulation
+        How many days the social distancing last. Use -1 to make the restriction last till the end of the simulation
 
     social_distance_strictness: int
         How strict from 0 to 4 the social distancing measures are. 
@@ -86,18 +87,10 @@ def run_simulation(n_of_families = 500,
     seed: int
         The random seed value
 
-    dump: bool
-        If true dump networks to file, otherwise return the networks list
-        NB, if network simulation is too heavy, the dump can crash
-
-    path:string
-        The path to the file/folder where the networks will be saved
-
     Return
     ------
 
-    nets:list
-        List of nets of the simulation
+    None. It saves the dumps of the networks in the path folder
 
     """
     # generate new edges
@@ -108,57 +101,21 @@ def run_simulation(n_of_families = 500,
     else:
         np.random.seed(int(time.time()))
         random.seed(time.time())
-    
-    # check values
-    if n_of_families < 10:
-        print("Invalid number of families. Use at least 10 families")
-        sys.exit()
-    if use_steps:
-        if number_of_steps < 0:
-            print("Invalid number of steps")
-            sys.exit()
-    if infection_duration < 0:
-        print("Invalid infection duration")
-        sys.exit()
-    if incubation_days < 0 or incubation_days >= infection_duration:
-        print("Invalid incubation duration")
-        sys.exit()
-    if initial_day_restriction < 0 :
-        print("Invalid initial day social distancing")
-        sys.exit()
-    if social_distance_strictness < 0 or social_distance_strictness > 4:
-        print("Invalid social distancing value")
-        sys.exit()
-    if n_initial_infected_nodes < 0 or n_initial_infected_nodes > n_of_families:
-        print("Invalid number of initial infected nodes")
-        sys.exit()
-    if R_0 < 0:
-        print("Invalid value of R0")
-        sys.exit()
-    if n_test < 0:
-        print("Invalid number of test per day")
-        sys.exit()
-    if not (policy_test == "Random" or policy_test == "Degree Centrality" or policy_test == "Betweenness Centrality"):
-        print("Invalid test strategy")
-        sys.exit()
-    if contact_tracking_efficiency < 0 or contact_tracking_efficiency > 1:
-        print("Invalid contact tracing efficiency")
-        sys.exit()
-    if restriction_duration < 0:
-        print("Invalid restriction restriction_duration")
-        sys.exit()
-    if restriction_duration == 0:
-        restriction_decreasing = False
-        social_distance_strictness = 0
-    if social_distance_strictness == 0:
-        restriction_decreasing = False
-        restriction_duration = 0
 
 
+    # clear folder
+    file_list = os.listdir(path)
+
+    for item in file_list:
+        if item.endswith(".pickle"):
+            os.remove(os.path.join(path, item))
+
     # init network
     G = generate_network(n_of_families)
     infection_rate = compute_IR(G, R_0, infection_duration, incubation_days)
     init_infection(G, n_initial_infected_nodes)
+    dump_network(G, path + "/initial_network")
+
     nets = list()
 
     if use_steps:
@@ -166,7 +123,8 @@ def run_simulation(n_of_families = 500,
             report, net= step(G, sim_index, incubation_days, infection_duration, infection_rate,
                              initial_day_restriction, restriction_duration, social_distance_strictness, 
                              restriction_decreasing, nets, n_test, policy_test, contact_tracking_efficiency)
-            nets.append(net.copy())
+            nets.append(net)
+            dump_network(G, path + "/network{}".format(sim_index))
     else:
         exposed = n_initial_infected_nodes
         infected = 0
@@ -175,29 +133,16 @@ def run_simulation(n_of_families = 500,
             report, net= step(G, sim_index, incubation_days, infection_duration, infection_rate,
                              initial_day_restriction, restriction_duration, social_distance_strictness, 
                              restriction_decreasing, nets, n_test, policy_test, contact_tracking_efficiency)
-            nets.append(net.copy())
+            nets.append(net)
+            dump_network(G, path + "/network{}".format(sim_index))
             sim_index += 1
             infected = report["I"]
             exposed = report["E"]
 
             if infected + exposed == 0:
                 break
-    if dump:
-        try:
-            with open(Path(path + ".pickle"), "wb") as f:
-                pickle.dump(nets, f)
-        except:
-            print("Simulation is too big to be dumped, try dumping in separated files. Note that this operation will be slow")
-            try:
-            	for i in range(len(nets)):
-            		dump_network(net, Path(path + "_network{}.pickle".format(i)))
-            except:
-            	print("Cannot dump network, the single network is too big. Please deactivate the dump option")
-            	sys.exit(-1)
-    
-    print("\n Simulation ended successfully \n You can find the dumped networks in the choosen folder \n")
 
-    return nets
+    print("\n Simulation ended successfully \n You can find the dumped networks in the choosen folder \n")
 
 def main():
 
@@ -217,7 +162,6 @@ def main():
     contact_tracking_efficiency = None
     use_random_seed = None
     seed = None
-    dump = True
     path = None
 
     user_interaction = int(input("Press 0 to load the default values or 1 to manually input the configuration for the simulation: "))
@@ -230,7 +174,7 @@ def main():
         incubation_days = int(input("Please insert the disease incubation duration: "))
         infection_duration = int(input("Please insert the disease duration: "))
         initial_day_restriction = int(input("Please insert the step index from which the social distance is applied: "))
-        restriction_duration = int(input("Please insert the number of days which the social distance last. Insert 0 to make the restriction last for all the simulation: "))
+        restriction_duration = int(input("Please insert the number of days which the social distance last. Insert -1 to make the restriction last for all the simulation: "))
         social_distance_strictness = int(input("Please insert a value between 0 and 4 to set the social distance strictness: "))
         restriction_decreasing = int(input("Press 0 to make the strictness of the social distance decrease during the simulation or 1 to keep it fixed: "))
         n_initial_infected_nodes = int(input("Please insert the number of initial infected individuals: "))
@@ -241,14 +185,56 @@ def main():
         use_random_seed = int(input("Press 1 use a fixed a random seed or 0 to pick a random seed: "))
         if use_random_seed:
             seed = int(input("Please insert the random seed: "))
-        path = input("Please insert the path with the file to dump. Please omit file type, that will be set automatically: ")
+        path = input("Please insert the path to a folder for dumps: ")    
 
-        run_simulation(n_of_families, use_steps, number_of_steps, incubation_days, infection_duration,
+        # check value
+        if n_of_families < 0:
+            print("Invalid number of families")
+            sys.exit()
+        if use_steps:
+            if number_of_steps < 0:
+                print("Invalid number of steps")
+                sys.exit()
+        if infection_duration < 0:
+            print("Invalid infection duration")
+            sys.exit()
+        if incubation_days < 0 or incubation_days >= infection_duration:
+            print("Invalid incubation duration")
+            sys.exit()
+        if initial_day_restriction < 0 :
+            print("Invalid initial day social distancing")
+            sys.exit()
+        if social_distance_strictness < 0 or social_distance_strictness > 4:
+            print("Invalid social distancing value")
+            sys.exit()
+        if n_initial_infected_nodes < 0 or n_initial_infected_nodes > n_of_families:
+            print("Invalid number of initial infected nodes")
+            sys.exit()
+        if R_0 < 0:
+            print("Invalid value of R0")
+            sys.exit()
+        if n_test < 0:
+            print("Invalid number of test per day")
+            sys.exit()
+        if not (policy_test == "Random" or policy_test == "Degree Centrality" or policy_test == "Betweenness Centrality"):
+            print("Invalid test strategy")
+            sys.exit()
+        if contact_tracking_efficiency < 0 or contact_tracking_efficiency > 1:
+            print("Invalid contact tracing efficiency")
+            sys.exit()
+        if restriction_duration < -1:
+            print("Invalid restriction restriction_duration")
+            sys.exit()
+        if     restriction_duration == -1:
+            restriction_decreasing = False
+            restriction_duration = False        
+
+        run_simulation(path, n_of_families, use_steps, number_of_steps, incubation_days, infection_duration,
             initial_day_restriction, restriction_duration, social_distance_strictness, restriction_decreasing,
-            n_initial_infected_nodes, R_0, n_test, policy_test, contact_tracking_efficiency, use_random_seed, seed, dump, path)
+            n_initial_infected_nodes, R_0, n_test, policy_test, contact_tracking_efficiency, use_random_seed, seed, path)
     else:
-        path = input("Please insert the path with the file to dump. Please omit file type, that will be set automatically: ")
-        run_simulation(path = path, dump = True)
+        path = input("Please insert the path to a folder for dumps: ")
+        run_simulation(path = path)
 
 if __name__ == "__main__":
     main()
\ No newline at end of file
